@@ -342,9 +342,11 @@ struct request *Request_Strip_Header(struct request *sr, char *request_body)
 	sr->keep_alive=VAR_OFF;
 	if((strstr2(request_body, RH_CONNECTION))!=NULL && sr->protocol==HTTP_11){
 		sr->connection = Request_Find_Variable(request_body, RH_CONNECTION);
-		if((strstr2(sr->connection,"Keep-Alive"))!=NULL){
-			sr->keep_alive=VAR_ON;
-		}
+                if(sr->connection){
+                  if((strstr2(sr->connection,"Keep-Alive"))!=NULL){
+                    sr->keep_alive=VAR_ON;
+                  }
+                }
 	}
 	
 	sr->accept			= Request_Find_Variable(request_body, RH_ACCEPT);
